import re
import os
import execjs
import coffeescript

EngineError = execjs.RuntimeError
CompilationError = execjs.ProgramError
bundled_path = os.path.join(os.path.abspath(os.path.dirname(__file__)), "eco.js")
version_ptn = re.compile(".+Eco Compiler (.*).*")

class Source(object):

    def __init__(self):
        self._path = ""
        self._contents = ""
        self._version = ""
        self._context = ""
        self._combined_contents = ""

    def path(self, path=None):
        if path:
            self._contents = self._version = self._context = None
        self._path = path or self._path or os.environ.get("ECO_SOURCE_PATH") or bundled_path
        return self._path

    @property
    def contents(self):
        self._contents = self._contents or open(self.path()).read()
        return self._contents

    @property
    def combined_contents(self):
        return ";\n".join([coffeescript._default_compiler_script(), self.contents])

    @property
    def version(self):
        self._version = self._version or version_ptn.search(self.contents).group(1)
        return self._version

    @property
    def context(self):
        self._context = self._context or execjs.compile(self.combined_contents)
        return self._context


source = Source()


def version():
    return source.version

def compile(template):
    template_ = template.read() if hasattr(template, "read") else template
    return source.context.call("eco.precompile", template_)

def context_for(template):
    return execjs.compile("var render = {0}".format(compile(template)))

def render(template, **locals_kw):
    return context_for(template).call("render", locals_kw)


import os
from setuptools import setup


version = '0.9.1'
name = 'eco'
short_description = 'Python Eco is a bridge to the ECO(CoffeeScript Template) compiler.'
long_description = """\

Python Eco is a bridge to the `Eco <https://github.com/sstephenson/eco>`_ (CoffeeScript Template) compiler.

**Python Eco**
===============

::

    import eco

    eco.compile(open("template.eco"))
    # Out: u"function(...) {...}"

    context = eco.context_for("Hello <%= @name %>")
    context.call("render", {"name": "Sam"})
    # Out: u'Hello Sam'

    eco.render("Hello <%= @name %>", name="world")
    # Out: u'Hello world'

Requirements
============
* CoffeeScript

Setup
=====

::

    $ pip install eco


History
========
0.9.x (2012-06-17)
~~~~~~~~~~~~~~~~~
* first release

License
========
MIT License
"""

root_dir = os.path.dirname(__file__)
if root_dir != '':
    os.chdir(root_dir)

setup(
    name=name,
    version=version,
    description=short_description,
    long_description=long_description,
    classifiers=[
       "Development Status :: 4 - Beta",
       "Development Status :: 5 - Production/Stable",
       'Environment :: Console',
       "Environment :: Web Environment",
       "Intended Audience :: Developers",
       'License :: OSI Approved :: MIT License',
       "Programming Language :: Python :: 2",
       "Programming Language :: Python :: 2.6",
       "Programming Language :: Python :: 2.7",
       "Programming Language :: Python :: 3",
       "Programming Language :: Python :: 3.1",
       "Programming Language :: Python :: 3.2",
       'Topic :: Utilities',
       'Topic :: Software Development :: Libraries :: Python Modules',
    ],
    keywords=['javascript', 'coffeescript', 'eco', 'compiler'],
    author='Tatsuo Ikeda',
    author_email='jp.ne.co.jp at gmail',
    url='https://github.com/ikeikeikeike/python-eco',
    license='MIT License',
    packages=['eco'],
    package_dir={'eco': 'eco'},
    package_data={'eco': ['eco.js', '__init__.py'],},
    py_modules=['eco'],
    install_requires=['CoffeeScript'],
    test_suite="test_eco",
)
